@@ -6,7 +6,7 @@
  * mpage:    a program to reduce pages of print so that several pages
  *           of output appear on one printed page.
  *
- * Copyright (c) 1994-1999 Marcel J.E. Mol, The Netherlands
+ * Copyright (c) 1994-2004 Marcel J.E. Mol, The Netherlands
  * Copyright (c) 1988 Mark P. Hahn, Herndon, Virginia
  *  
  *     Permission is granted to anyone to make or distribute verbatim
@@ -33,6 +33,7 @@ do_args(int argc, char **argv, int envflag)
 {
     char *optstr;
     int consumed;
+    int finished;
     int currarg;
     int opterrors;
 
@@ -46,10 +47,16 @@ do_args(int argc, char **argv, int envflag)
     }
 
 #define OPTARG()  \
-    { consumed = 1; if(*++optstr == '\0') optstr = argv[++currarg]; }
+    { char opt = *optstr; \
+      consumed = 1; if(*++optstr == '\0') optstr = argv[++currarg]; \
+      if (!optstr) { fprintf (stderr, "%s: -%c: option requires argument\n", \
+                    MPAGE, opt); return -1; } \
+    }
+
 
     opterrors = 0;
-    for (currarg = 1; currarg < argc; currarg++) {
+    finished = 0;
+    for (currarg = 1; !finished && currarg < argc; currarg++) {
         if (*argv[currarg] != '-') {
             if (envflag)
                 opterrors++;
@@ -64,6 +71,9 @@ do_args(int argc, char **argv, int envflag)
                                         MPAGE, *optstr);
                         opterrors++;
                         break;
+                case '-':
+                        finished = 1;
+                        break;
                 case '1':
                         sheetindex = 0;
                         break;
@@ -81,7 +91,7 @@ do_args(int argc, char **argv, int envflag)
                                      UPDOWN : LEFTRIGHT;
                         break;
                 case 'A':    /* A4 sized, european paper */
-                        opt_page = "A4";
+                        opt_page = "A4"; /* deprecated */
                         break;
                 case 'b':     /* base paper type */
                         OPTARG();
@@ -382,12 +392,19 @@ do_args(int argc, char **argv, int envflag)
                 case 'T':
                         opt_tumble = 1 - opt_tumble;
                         break;
+                case 'u':
+                        check_utf8 = 1 - check_utf8;
+                        break;
                 case 'U':    /* Letter sized, US paper */
-                        opt_page = "Letter";
+                        opt_page = "Letter"; /* deprecated */
                         break;
                 case 'v':    /* verbose (print page count) */
                         opt_verbose = 1 - opt_verbose;
                         break;
+                case 'V':    /* Version */
+                        fprintf(stderr, "mpage version %s\n", VERSION);
+                        exit(0);
+                        break;
                 case 'W':
                         OPTARG();
                         opt_width = atoi(optstr);
