@@ -168,7 +168,7 @@ do_stdin(asheet, outfd)
      * but the tmpfilename
      */
      
-    (void) strcpy(tmpfile, "/usr/tmp/mpage-stdin-XXXXXX");
+    (void) strcpy(tmpfile, "/tmp/mpage-stdin-XXXXXX");
     if ( (tmpfd = mkstemp(tmpfile)) == -1) {
         fprintf(stderr, "%s: cannot create temporary file", MPAGE);
         perror(MPAGE);
@@ -209,7 +209,7 @@ do_stdin(asheet, outfd)
          * a temporary file; this temporary file will then
          * be used as input to the do_doc routine
          */
-        (void)strcpy(tmpfile, "/usr/tmp/mpageXXXXXX");
+        (void)strcpy(tmpfile, "/tmp/mpageXXXXXX");
         if ( (tmpfd = mkstemp(tmpfile)) == -1) {
             fprintf(stderr, "%s: cannot create temporary file", MPAGE);
             perror(MPAGE);
@@ -257,9 +257,10 @@ do_stdin(asheet, outfd)
         if ((fd = fopen(tmpfile, "r")) == NULL) {
             fprintf(stderr, "%s: cannot open %s\n", MPAGE, tmpfile);
             perror(MPAGE);
-        } else {
+        }
+        else {
 	    /*
-	     * check that the input is whether UTF-8 or not
+	     * check if the input is UTF-8 or not
 	     */
 	    if (looks_utf8 (fd))
 		use_utf8 = 1;
@@ -280,7 +281,7 @@ do_stdin(asheet, outfd)
 	/*
 	 * store the input to the temporary file to guess encoding correctly
 	 */
-        (void)strcpy(tmpfile, "/usr/tmp/mpageXXXXXX");
+        (void)strcpy(tmpfile, "/tmp/mpageXXXXXX");
         if ( (tmpfd = mkstemp(tmpfile)) == -1) {
             fprintf(stderr, "%s: cannot create temporary file", MPAGE);
 	    tmpfile[0] = 0;
