@@ -384,7 +384,7 @@ void usage(int errcode)
 {
     fprintf(stderr, "\
  mpage - print multiple pages on postscript, version %s\n\n\
- mpage [-1248acEfHlkoOrRStvuVxX] [-b papersize] [-Btextboxmargin]\n\
+ mpage [-1248aceEfHlkoOrRStTvuVxX] [-b papersize] [-Btextboxmargin]\n\
        [-C [encodingfile]] [-da|p] [-D dateformat] [-F fontname]\n\
        [-h header] [-I indent] [-j pagespec] [-J startpageno] [-L lines]\n\
        [-msheetmargin] [-Mpagemargin] [-p[prprog]] [-P[printer]]\n\
@@ -425,7 +425,7 @@ void usage(int errcode)
     fontname, opt_tabstop, PAGE_DEF, printprog, printarg,
     opt_duplex ? "on" : "off"
     );
-    fprintf(stderr, "\n(c) 1993-2004 Marcel Mol, marcel@mesa.nl (MESA Consulting)\n");
+    fprintf(stderr, "\n(c) 1993-2005 Marcel Mol, marcel@mesa.nl (MESA Consulting)\n");
 
     return;
 
