@@ -21,6 +21,39 @@
 #include "mpage.h"
 #include "string.h"
 
+#define PAPERSIZE_FILE  "/etc/papersize"
+void
+check_papersize()
+{
+    FILE * psfp;
+    char buf[LINESIZE];
+    
+    if (access(PAPERSIZE_FILE, R_OK))
+        return; /* no access or no papersize file. Just do nothing */
+
+    if ((psfp = fopen(PAPERSIZE_FILE, "r")) == NULL)
+        return; /* no access or no papersize file. Just do nothing */
+
+    while (fgets(buf, LINESIZE, psfp) != NULL) {
+        int i = 0;
+        int j = strlen(buf);
+
+        while (i < j && (buf[i] == ' ' || buf[i] == '\t'))
+            i++; /* skip leading space */
+        while (--j >= 0 && (buf[j] == ' ' || buf[j] == '\t' || buf[j] == '\n' || buf[j] == '\r'))
+            buf[j] = '\0'; /* skip trailing space */
+
+        if (strlen(buf + i) && buf[i] != '#' ) {
+            select_pagetype(buf + i);
+            break;
+        }
+    }
+
+    fclose (psfp);
+
+    return;
+
+} /* check_papersize */
 
 
 void
