@@ -6,7 +6,7 @@
  * mpage:    a program to reduce pages of print so that several pages
  *           of output appear on one printed page.
  *
- * Copyright (c) 1994-1999 Marcel J.E. Mol, The Netherlands
+ * Copyright (c) 1994-2004 Marcel J.E. Mol, The Netherlands
  * Copyright (c) 1988 Mark P. Hahn, Herndon, Virginia
  *  
  *     Permission is granted to anyone to make or distribute verbatim
@@ -727,8 +727,8 @@ do_post_sheet(fd, asheet, outfd)
          * Take extra page margins into account
          */
         fprintf(outfd, "%d %d div %d %d div scale\n",
-               ps_width - pagemargin_left - pagemargin_right, ps_width,
-               ps_height - pagemargin_top - pagemargin_bottom, ps_height);
+               ps_width, ps_width + pagemargin_left + pagemargin_right,
+               ps_height, ps_height + pagemargin_top + pagemargin_bottom);
 #ifndef NSCALE
         fprintf(outfd, "%d %d translate\n", pagemargin_left, pagemargin_bottom);
 #endif
@@ -864,8 +864,8 @@ do_post_sheet(fd, asheet, outfd)
          * Take extra page margins into account
          */
         fprintf(outfd, "%d %d div %d %d div scale\n",
-               ps_width - pagemargin_left - pagemargin_right, ps_width,
-               ps_height - pagemargin_top - pagemargin_bottom, ps_height);
+               ps_width, ps_width + pagemargin_left + pagemargin_right,
+               ps_height, ps_height + pagemargin_top + pagemargin_bottom);
 #ifndef NSCALE
         fprintf(outfd, "%d %d translate\n", pagemargin_left, pagemargin_bottom);
 #endif
