@@ -6,7 +6,7 @@
  * mpage:    a program to reduce pages of print so that several pages
  *           of output appear on one printed sheet.
  *
- * Copyright (c) 1994-1999 Marcel J.E. Mol, The Netherlands
+ * Copyright (c) 1994-2004 Marcel J.E. Mol, The Netherlands
  * Copyright (c) 1988 Mark P. Hahn, Herndon, Virginia
  *  
  *     Permission is granted to anyone to make or distribute verbatim
@@ -201,9 +201,14 @@ do_text_sheet(fd, asheet, outfd)
                                asheet->sh_cwidth, file_pagenum, pos);
                 fprintf(outfd, " (Page %d) show\n", file_pagenum);
                 fprintf(outfd, "fnamefont setfont\n");
+#if 0 /* seems stringvals cannot be dup-ed... */
+                fprintf(outfd, "(%s) dup stringwidth pop sub 2 div %d moveto show\n",
+                               file_name, pos);
+#else
                 fprintf(outfd, "(%s) stringwidth pop sub 2 div %d moveto\n",
                                file_name, pos);
                 fprintf(outfd, "(%s) show\n", file_name);
+#endif
             }
         }
 
@@ -218,7 +223,23 @@ do_text_sheet(fd, asheet, outfd)
                asheet->sh_plength * fsize - pagemargin_top - pagemargin_bottom,
                asheet->sh_plength * fsize);
 
-        fprintf(outfd, "textfont setfont\n");
+	/*
+         * not sure, selection of correct font is difficult.
+	 * so guessing it from locale, and always use it for UTF-8
+	 */
+	if (use_utf8 && current_locale) {
+		if (!strncmp (current_locale, "ja_JP", 5))
+		    fprintf (outfd, "unijis setfont\n");
+		else if (!strncmp (current_locale, "ko_KR", 5))
+		    fprintf (outfd, "uniks setfont\n");
+		else if (!strncmp (current_locale, "zh_CN", 5))
+		    fprintf (outfd, "unigb setfont\n");
+		else if (!strncmp (current_locale, "zh_TW", 5))
+		    fprintf (outfd, "unicns setfont\n");
+		else
+		    fprintf (outfd, "textfont setfont\n");
+	} else
+            fprintf(outfd, "textfont setfont\n");
 
         /*
          * place one reduced page on the printed page
@@ -302,8 +323,8 @@ text_onepage(file, asheet, outfd)
             }
             else {                /* zenkaku */
                 if (loadfont != 1) {
-                     fprintf(outfd, "kanj setfont\n");
-                     loadfont = 1;
+                    fprintf(outfd, "kanj setfont\n");
+                    loadfont = 1;
                 }
             }
             i = loc.pl_col;
@@ -325,8 +346,8 @@ text_onepage(file, asheet, outfd)
 
         }
         else if (loadfont) {
-           fprintf(outfd, "textfont setfont\n");
-           loadfont = 0;
+            fprintf(outfd, "textfont setfont\n");
+            loadfont = 0;
         }
 #endif
         Debug(DB_ONEPAGE, "%% text = %d\n", text);
@@ -399,6 +420,50 @@ mp_get_text(infile, locp, asheet, kp)
      * may need to put 5 characters plus NULL in it.
      */
     while (gathering && textp - text < LINESIZE - 5) {
+	if (use_utf8) {
+	    int c, i;
+	    size_t len;
+	    char uni[7];
+
+#ifdef KANJI
+	    *kp = 0;
+#endif
+	    if (prevchar) {
+		c = prevchar;
+		prevchar = 0;
+	    } else
+		c = fgetc (infile);
+
+	    if (c < 128) len = 1;
+	    else if ((c & 0xe0) == 0xc0) len = 2;
+	    else if ((c & 0xf0) == 0xe0) len = 3;
+	    else if ((c & 0xf8) == 0xf0) len = 4;
+	    else if ((c & 0xfc) == 0xf8) len = 5;
+	    else if ((c & 0xfe) == 0xfc) len = 6;
+	    else {
+		fprintf (stderr, "Invalid UTF-8\n");
+		len = 1;
+	    }
+	    if (len > 1) {
+		uni[0] = c;
+		for (i = 1; i < len; i++) {
+		    c = fgetc (infile);
+		    if ((c & 0xc0) != 0x80) {
+			fprintf (stderr, "Invalid UTF-8\n");
+			break;
+		    }
+		    uni[i] = c;
+		}
+		uni[i] = 0;
+		/* FIXME: need to decide a width of glyph */
+		locp->pl_new_col += 2;
+		for (i = 0; uni[i]; i++)
+		    *textp++ = uni[i];
+		continue;
+	    } else {
+		ichr = c;
+	    }
+	} else {
 #ifdef KANJI
         if (current_locale && !strncmp(current_locale,"ja_JP",5)) {
             if (prevkanj) {
@@ -452,6 +517,7 @@ mp_get_text(infile, locp, asheet, kp)
 #ifdef KANJI
 	}
 #endif
+	}
         Debug(DB_GETLINE, "%%called fgetc ichr = %d", ichr);
         /*
          * this prevents nulls in the input from confusing the
